@@ -2,8 +2,7 @@
 Rate limiting with commonly used storage backends
 """
 
-from . import aio, storage, strategies
-from ._version import get_versions
+from . import _version, aio, storage, strategies
 from .limits import (
     RateLimitItem,
     RateLimitItemPerDay,
@@ -15,9 +14,6 @@ from .limits import (
 )
 from .util import parse, parse_many
 
-__version__ = get_versions()["version"]
-del get_versions
-
 __all__ = [
     "RateLimitItem",
     "RateLimitItemPerYear",
@@ -32,3 +28,5 @@ __all__ = [
     "parse",
     "parse_many",
 ]
+
+__version__ = _version.get_versions()["version"]
