@@ -1,11 +1,13 @@
 import time
 from typing import Any, Optional, Tuple
 
+from packaging.version import Version
+
 from ..util import get_package_data
 from .base import MovingWindowSupport, Storage
 
 
-class RedisInteractor(object):
+class RedisInteractor:
     RES_DIR = "resources/redis/lua_scripts"
 
     SCRIPT_MOVING_WINDOW = get_package_data(f"{RES_DIR}/moving_window.lua")
@@ -109,7 +111,7 @@ class RedisStorage(RedisInteractor, Storage, MovingWindowSupport):
     STORAGE_SCHEME = ["redis", "rediss", "redis+unix"]
     """The storage scheme for redis"""
 
-    DEPENDENCIES = ["redis"]
+    DEPENDENCIES = {"redis": Version("3.0")}
 
     def __init__(
         self,
